"use client";
import { useState, useEffect } from "react";

interface JobPosting {
  id: number; // Assuming each job has an id
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

async function fetchJobs(): Promise<JobPosting[]> {
  const response = await fetch("http://51.20.250.24/jobs");
  if (!response.ok) {
    throw new Error("Failed to fetch jobs");
  }
  return response.json();
}

export default function Home() {
  const [jobs, setJobs] = useState<JobPosting[]>([]);

  useEffect(() => {
    const getJobs = async () => {
      try {
        const jobsData = await fetchJobs();
        setJobs(jobsData);
      } catch (error) {
        console.error("Error fetching jobs:", error);
      }
    };
    getJobs();
  }, []);

  return (
    <main className="">
      {jobs.map((job) => (
        <div key={job.id}>
          <h2>{job.title}</h2>
          <p>
            {job.company} - {job.location}
          </p>
          <p>{job.type}</p>
          <p>{job.description}</p>
          <a href={job.link} target="_blank" rel="noopener noreferrer">
            Link
          </a>
          <p>
            Skills:{" "}
            {Object.keys(job.skills)
              .filter((skill) => job.skills[skill as keyof typeof job.skills])
              .join(", ")}
          </p>
        </div>
      ))}
    </main>
  );
}
